@@ -22,5 +22,13 @@ configs = {
 		usdc_mint_address=PublicKey('8zGuJQqwhZafTah7Uc7Z4tXRnguqkn5KLFAP8oV6PHe2'),
 		markets=devnet_markets,
 		banks=devnet_banks,
+    ), 
+    "mainnet": Config(
+        env='mainnet',
+        pyth_oracle_mapping_address=PublicKey('AHtgzX45WTKfkPG53L6WYhGEXwQkN1BVknET3sVsLL8J'),
+		clearing_house_program_id=PublicKey('dRiftyHA39MWEi3m9aunc5MzRF1JYuBsbn6VPcn33UH'),
+		usdc_mint_address=PublicKey('EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v'),
+        markets=None, 
+        banks=None
     )
 }
